/**
 * @file
 * VuoList_VuoDispersion C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoDispersion_H
#define VuoList_VuoDispersion_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoDispersion VuoList_VuoDispersion
 * A list of @ref VuoDispersion elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

#if defined(DOXYGEN) || !defined(VuoList_VuoDispersion_TYPE_DEFINED)
/// @{
/**
 * A list of @ref VuoDispersion elements.
 */
typedef void * VuoList_VuoDispersion;
/// @}
#endif

/**
 * Creates a new list of @ref VuoDispersion elements.
 */
VuoList_VuoDispersion VuoListCreate_VuoDispersion(void);

/**
 * Returns the @ref VuoDispersion at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoDispersion VuoListGetValueAtIndex_VuoDispersion(const VuoList_VuoDispersion list, const unsigned long index);

/**
 * Changes the @ref VuoDispersion at @c index.
 * Index values start at 1.
 * If the list has no items, nothing is changed.
 * Attempting to change an out-of-bounds index changes the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
void VuoListSetValueAtIndex_VuoDispersion(const VuoList_VuoDispersion list, const VuoDispersion value, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoDispersion(VuoList_VuoDispersion list, const VuoDispersion value);

/**
 * Removes the first value from @c list.
 */
void VuoListRemoveFirstValue_VuoDispersion(VuoList_VuoDispersion list);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoDispersion(VuoList_VuoDispersion list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoDispersion(VuoList_VuoDispersion list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoDispersion(const VuoList_VuoDispersion list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoDispersion VuoList_VuoDispersion_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoDispersion_jsonFromValue(const VuoList_VuoDispersion value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoDispersion_summaryFromValue(const VuoList_VuoDispersion value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoDispersion VuoList_VuoDispersion_valueFromString(const char *str);
char * VuoList_VuoDispersion_stringFromValue(const VuoList_VuoDispersion value);
/// @}

/**
 * @}
 */

#endif
