/**
 * @file
 * VuoList_VuoFont C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoFont_H
#define VuoList_VuoFont_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoFont VuoList_VuoFont
 * A list of @ref VuoFont elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

#if defined(DOXYGEN) || !defined(VuoList_VuoFont_TYPE_DEFINED)
/// @{
/**
 * A list of @ref VuoFont elements.
 */
typedef void * VuoList_VuoFont;
/// @}
#endif

/**
 * Creates a new list of @ref VuoFont elements.
 */
VuoList_VuoFont VuoListCreate_VuoFont(void);

/**
 * Returns the @ref VuoFont at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoFont VuoListGetValueAtIndex_VuoFont(const VuoList_VuoFont list, const unsigned long index);

/**
 * Changes the @ref VuoFont at @c index.
 * Index values start at 1.
 * If the list has no items, nothing is changed.
 * Attempting to change an out-of-bounds index changes the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
void VuoListSetValueAtIndex_VuoFont(const VuoList_VuoFont list, const VuoFont value, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoFont(VuoList_VuoFont list, const VuoFont value);

/**
 * Removes the first value from @c list.
 */
void VuoListRemoveFirstValue_VuoFont(VuoList_VuoFont list);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoFont(VuoList_VuoFont list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoFont(VuoList_VuoFont list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoFont(const VuoList_VuoFont list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoFont VuoList_VuoFont_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoFont_jsonFromValue(const VuoList_VuoFont value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoFont_summaryFromValue(const VuoList_VuoFont value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoFont VuoList_VuoFont_valueFromString(const char *str);
char * VuoList_VuoFont_stringFromValue(const VuoList_VuoFont value);
/// @}

/**
 * @}
 */

#endif
