/**
 * @file
 * VuoList_VuoLoopType C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoLoopType_H
#define VuoList_VuoLoopType_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoLoopType VuoList_VuoLoopType
 * A list of @ref VuoLoopType elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

#if defined(DOXYGEN) || !defined(VuoList_VuoLoopType_TYPE_DEFINED)
/// @{
/**
 * A list of @ref VuoLoopType elements.
 */
typedef void * VuoList_VuoLoopType;
/// @}
#endif

/**
 * Creates a new list of @ref VuoLoopType elements.
 */
VuoList_VuoLoopType VuoListCreate_VuoLoopType(void);

/**
 * Returns the @ref VuoLoopType at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoLoopType VuoListGetValueAtIndex_VuoLoopType(const VuoList_VuoLoopType list, const unsigned long index);

/**
 * Changes the @ref VuoLoopType at @c index.
 * Index values start at 1.
 * If the list has no items, nothing is changed.
 * Attempting to change an out-of-bounds index changes the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
void VuoListSetValueAtIndex_VuoLoopType(const VuoList_VuoLoopType list, const VuoLoopType value, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoLoopType(VuoList_VuoLoopType list, const VuoLoopType value);

/**
 * Removes the first value from @c list.
 */
void VuoListRemoveFirstValue_VuoLoopType(VuoList_VuoLoopType list);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoLoopType(VuoList_VuoLoopType list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoLoopType(VuoList_VuoLoopType list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoLoopType(const VuoList_VuoLoopType list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoLoopType VuoList_VuoLoopType_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoLoopType_jsonFromValue(const VuoList_VuoLoopType value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoLoopType_summaryFromValue(const VuoList_VuoLoopType value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoLoopType VuoList_VuoLoopType_valueFromString(const char *str);
char * VuoList_VuoLoopType_stringFromValue(const VuoList_VuoLoopType value);
/// @}

/**
 * @}
 */

#endif
