/**
 * @file
 * VuoList_VuoScreen C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoScreen_H
#define VuoList_VuoScreen_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoScreen VuoList_VuoScreen
 * A list of @ref VuoScreen elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

#if defined(DOXYGEN) || !defined(VuoList_VuoScreen_TYPE_DEFINED)
/// @{
/**
 * A list of @ref VuoScreen elements.
 */
typedef void * VuoList_VuoScreen;
/// @}
#endif

/**
 * Creates a new list of @ref VuoScreen elements.
 */
VuoList_VuoScreen VuoListCreate_VuoScreen(void);

/**
 * Returns the @ref VuoScreen at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoScreen VuoListGetValueAtIndex_VuoScreen(const VuoList_VuoScreen list, const unsigned long index);

/**
 * Changes the @ref VuoScreen at @c index.
 * Index values start at 1.
 * If the list has no items, nothing is changed.
 * Attempting to change an out-of-bounds index changes the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
void VuoListSetValueAtIndex_VuoScreen(const VuoList_VuoScreen list, const VuoScreen value, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoScreen(VuoList_VuoScreen list, const VuoScreen value);

/**
 * Removes the first value from @c list.
 */
void VuoListRemoveFirstValue_VuoScreen(VuoList_VuoScreen list);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoScreen(VuoList_VuoScreen list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoScreen(VuoList_VuoScreen list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoScreen(const VuoList_VuoScreen list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoScreen VuoList_VuoScreen_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoScreen_jsonFromValue(const VuoList_VuoScreen value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoScreen_summaryFromValue(const VuoList_VuoScreen value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoScreen VuoList_VuoScreen_valueFromString(const char *str);
char * VuoList_VuoScreen_stringFromValue(const VuoList_VuoScreen value);
/// @}

/**
 * @}
 */

#endif
