/**
 * @file
 * VuoList_VuoShader C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoShader_H
#define VuoList_VuoShader_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoShader VuoList_VuoShader
 * A list of @ref VuoShader elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

#if defined(DOXYGEN) || !defined(VuoList_VuoShader_TYPE_DEFINED)
/// @{
/**
 * A list of @ref VuoShader elements.
 */
typedef void * VuoList_VuoShader;
/// @}
#endif

/**
 * Creates a new list of @ref VuoShader elements.
 */
VuoList_VuoShader VuoListCreate_VuoShader(void);

/**
 * Returns the @ref VuoShader at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoShader VuoListGetValueAtIndex_VuoShader(const VuoList_VuoShader list, const unsigned long index);

/**
 * Changes the @ref VuoShader at @c index.
 * Index values start at 1.
 * If the list has no items, nothing is changed.
 * Attempting to change an out-of-bounds index changes the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
void VuoListSetValueAtIndex_VuoShader(const VuoList_VuoShader list, const VuoShader value, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoShader(VuoList_VuoShader list, const VuoShader value);

/**
 * Removes the first value from @c list.
 */
void VuoListRemoveFirstValue_VuoShader(VuoList_VuoShader list);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoShader(VuoList_VuoShader list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoShader(VuoList_VuoShader list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoShader(const VuoList_VuoShader list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoShader VuoList_VuoShader_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoShader_jsonFromValue(const VuoList_VuoShader value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoShader_summaryFromValue(const VuoList_VuoShader value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoShader VuoList_VuoShader_valueFromString(const char *str);
char * VuoList_VuoShader_stringFromValue(const VuoList_VuoShader value);
/// @}

/**
 * @}
 */

#endif
