/**
 * @file
 * VuoList_VuoVerticalAlignment C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoVerticalAlignment_H
#define VuoList_VuoVerticalAlignment_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoVerticalAlignment VuoList_VuoVerticalAlignment
 * A list of @ref VuoVerticalAlignment elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

#if defined(DOXYGEN) || !defined(VuoList_VuoVerticalAlignment_TYPE_DEFINED)
/// @{
/**
 * A list of @ref VuoVerticalAlignment elements.
 */
typedef void * VuoList_VuoVerticalAlignment;
/// @}
#endif

/**
 * Creates a new list of @ref VuoVerticalAlignment elements.
 */
VuoList_VuoVerticalAlignment VuoListCreate_VuoVerticalAlignment(void);

/**
 * Returns the @ref VuoVerticalAlignment at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoVerticalAlignment VuoListGetValueAtIndex_VuoVerticalAlignment(const VuoList_VuoVerticalAlignment list, const unsigned long index);

/**
 * Changes the @ref VuoVerticalAlignment at @c index.
 * Index values start at 1.
 * If the list has no items, nothing is changed.
 * Attempting to change an out-of-bounds index changes the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
void VuoListSetValueAtIndex_VuoVerticalAlignment(const VuoList_VuoVerticalAlignment list, const VuoVerticalAlignment value, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoVerticalAlignment(VuoList_VuoVerticalAlignment list, const VuoVerticalAlignment value);

/**
 * Removes the first value from @c list.
 */
void VuoListRemoveFirstValue_VuoVerticalAlignment(VuoList_VuoVerticalAlignment list);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoVerticalAlignment(VuoList_VuoVerticalAlignment list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoVerticalAlignment(VuoList_VuoVerticalAlignment list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoVerticalAlignment(const VuoList_VuoVerticalAlignment list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoVerticalAlignment VuoList_VuoVerticalAlignment_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoVerticalAlignment_jsonFromValue(const VuoList_VuoVerticalAlignment value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoVerticalAlignment_summaryFromValue(const VuoList_VuoVerticalAlignment value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoVerticalAlignment VuoList_VuoVerticalAlignment_valueFromString(const char *str);
char * VuoList_VuoVerticalAlignment_stringFromValue(const VuoList_VuoVerticalAlignment value);
/// @}

/**
 * @}
 */

#endif
