/**
 * @file
 * VuoList_VuoWindowProperty C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoWindowProperty_H
#define VuoList_VuoWindowProperty_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoWindowProperty VuoList_VuoWindowProperty
 * A list of @ref VuoWindowProperty elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

#if defined(DOXYGEN) || !defined(VuoList_VuoWindowProperty_TYPE_DEFINED)
/// @{
/**
 * A list of @ref VuoWindowProperty elements.
 */
typedef void * VuoList_VuoWindowProperty;
/// @}
#endif

/**
 * Creates a new list of @ref VuoWindowProperty elements.
 */
VuoList_VuoWindowProperty VuoListCreate_VuoWindowProperty(void);

/**
 * Returns the @ref VuoWindowProperty at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoWindowProperty VuoListGetValueAtIndex_VuoWindowProperty(const VuoList_VuoWindowProperty list, const unsigned long index);

/**
 * Changes the @ref VuoWindowProperty at @c index.
 * Index values start at 1.
 * If the list has no items, nothing is changed.
 * Attempting to change an out-of-bounds index changes the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
void VuoListSetValueAtIndex_VuoWindowProperty(const VuoList_VuoWindowProperty list, const VuoWindowProperty value, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoWindowProperty(VuoList_VuoWindowProperty list, const VuoWindowProperty value);

/**
 * Removes the first value from @c list.
 */
void VuoListRemoveFirstValue_VuoWindowProperty(VuoList_VuoWindowProperty list);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoWindowProperty(VuoList_VuoWindowProperty list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoWindowProperty(VuoList_VuoWindowProperty list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoWindowProperty(const VuoList_VuoWindowProperty list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoWindowProperty VuoList_VuoWindowProperty_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoWindowProperty_jsonFromValue(const VuoList_VuoWindowProperty value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoWindowProperty_summaryFromValue(const VuoList_VuoWindowProperty value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoWindowProperty VuoList_VuoWindowProperty_valueFromString(const char *str);
char * VuoList_VuoWindowProperty_stringFromValue(const VuoList_VuoWindowProperty value);
/// @}

/**
 * @}
 */

#endif
