/**
 * @file
 * VuoList_VuoWindowReference C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoWindowReference_H
#define VuoList_VuoWindowReference_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoWindowReference VuoList_VuoWindowReference
 * A list of @ref VuoWindowReference elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

#if defined(DOXYGEN) || !defined(VuoList_VuoWindowReference_TYPE_DEFINED)
/// @{
/**
 * A list of @ref VuoWindowReference elements.
 */
typedef void * VuoList_VuoWindowReference;
/// @}
#endif

/**
 * Creates a new list of @ref VuoWindowReference elements.
 */
VuoList_VuoWindowReference VuoListCreate_VuoWindowReference(void);

/**
 * Returns the @ref VuoWindowReference at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoWindowReference VuoListGetValueAtIndex_VuoWindowReference(const VuoList_VuoWindowReference list, const unsigned long index);

/**
 * Changes the @ref VuoWindowReference at @c index.
 * Index values start at 1.
 * If the list has no items, nothing is changed.
 * Attempting to change an out-of-bounds index changes the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
void VuoListSetValueAtIndex_VuoWindowReference(const VuoList_VuoWindowReference list, const VuoWindowReference value, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoWindowReference(VuoList_VuoWindowReference list, const VuoWindowReference value);

/**
 * Removes the first value from @c list.
 */
void VuoListRemoveFirstValue_VuoWindowReference(VuoList_VuoWindowReference list);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoWindowReference(VuoList_VuoWindowReference list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoWindowReference(VuoList_VuoWindowReference list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoWindowReference(const VuoList_VuoWindowReference list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoWindowReference VuoList_VuoWindowReference_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoWindowReference_jsonFromValue(const VuoList_VuoWindowReference value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoWindowReference_summaryFromValue(const VuoList_VuoWindowReference value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoWindowReference VuoList_VuoWindowReference_valueFromString(const char *str);
char * VuoList_VuoWindowReference_stringFromValue(const VuoList_VuoWindowReference value);
/// @}

/**
 * @}
 */

#endif
